@@ -262,12 +262,15 @@ class Plugin(plugins.BasePlugin):
                 return ds
         else:
             results = {}
-            diskdata = psutil.disk_io_counters(perdisk=True)
-            for device, values in diskdata.items():
-                device_stats = {}
-                for key_value in values._fields:
-                    device_stats[key_value] = getattr(values, key_value)
-                results[device] = device_stats
+            try:
+                diskdata = psutil.disk_io_counters(perdisk=True)
+                for device, values in diskdata.items():
+                    device_stats = {}
+                    for key_value in values._fields:
+                        device_stats[key_value] = getattr(values, key_value)
+                    results[device] = device_stats
+            except Exception as e:
+                results = e
             return results
 
 
